@@ -12,7 +12,7 @@ from typing import Optional
 import pandas as pd 
 
 os.environ["CUDA_VISIBLE_DEVICES"] = "-1" # Disable using GPU
-from tensorflow import keras as kr
+import keras as kr
 
 #-------------------------------------------------------------
 # First define/init some general variables/constants
